import { 
  select, 
  csv,
  json,
  format,
	scaleOrdinal,
	pie,
	arc,
	sum} from 'd3';


const render = (data, selector) => {
  const width = 960;
	const height = 400;
	const radius = Math.min(width, height) / 2;
  
  const plot_container = select('.' + selector)
  	.append("div")
  	.attr("class", "helper_div")

  const xAxisTickFormat = number =>
  	format('.4~g')(number);
  const plotVariable = d => d.MilkProduction;
  
  const colorScale = scaleOrdinal()
  	.domain(['India', 'U.S.', 'Pakistan','China','Brazil','Germany','Russian Federation','France'])
  	.range(['#3e3e97','#838690','#e56d26','	#ff5078','#0fff9d','#3d71e7','	#cfff0b','#b0d1e5']);
  
  const pie_calc = pie()
  	.value(plotVariable)(data);
  
  const arc = d3.arc()
		.outerRadius(radius - 10)
		.innerRadius(radius - 195)
  	.padAngle([1/60]) // as angle is specified in radians
  	.cornerRadius([10]);

	const labelArc = d3.arc()
		.outerRadius(radius - 100)
		.innerRadius(radius - 40);
  
  const g = plot_container
  .append('svg')
  	.attr('width', width)
  	.attr('height', height)
  .selectAll('arc').append('g')
  	.data(pie_calc)
  	.enter().append('g')
  	.attr('transform', `translate(${width/2}, ${height/2})`)
  	.attr('class', 'pie-slice');
  
	// select the svg area
var Svg = d3.select("#my_dataviz2")
  
  g.append('path')
		.attr('d', arc)
		.style('fill', d => colorScale(d.data.Country));
  
  g.append('text')
  	.attr('transform', d => 
         `translate(${labelArc.centroid(d)})`)
    .text(d => d.data.Country)
  	.attr('class', 'dounat-text');
  
  g.on("mouseover", d => {
    
    let total = sum(data.map(plotVariable))
    
    let percent = Math.round(1000 * d.data.MilkProduction / total) / 10;
    
    d3.select('#tooltip')
        .style('left', d3.event.pageX + 'px')
        .style('top', d3.event.pageY + 'px')
        .style('opacity', 1)
        .select('#value')
        .text(percent);
    
	})
    g.on('mouseout', () => {
      // Hide the tooltip
      d3.select('#tooltip')
        .style('opacity', 0);
		});
   
  // prevent tooltip to disappear when hovered 
  select('#tooltip').
  	on('mouseover', () => {
  		select('#tooltip').style('opacity', 1)
  });
   
}

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.MilkProduction = +d.MilkProduction;
  });
	render(data, 'plot_container');
});